@@ -4,8 +4,9 @@ use Moo;
 
 has value  => is => 'rw', default => 2;
 has merged => is => 'rw', default => 0;
-has appear => is => 'rw';
 
+# for animation
+has appearing     => is => 'rw', default => 0;
 has merging_tiles => is => 'rw';
 has moving_from   => is => 'rw';
 
